# Official Python STEEM Library
`steem-python` is the official STEEM library for Python. It comes with a BIP38 encrypted wallet and a practical CLI utility called `steempy`.

## Installation
You can install `steem-python` with `pip`:

```
pip install -U steem
```

## Documentation
Documentation is available at **http://steem.readthedocs.io**

## TODO
* more unit-tests
* 100% documentation coverage

## Notice
This library is under *active development*. Use at own discretion.

